""" This module loads all the classes from the VTK Text Analysis library into
its namespace.  This is an optional module."""

from vtkTextAnalysisPython import *
